@@ -281,6 +281,7 @@ and auxiliary coordinate roles for different data variables.
                                        #   fields.
                                        #-----------------------------
          'variable_attributes': variable_attributes,
+         'bounds' : {},
          # -----------------------------------------------------------
          # CFA parameters
          # -----------------------------------------------------------
@@ -1009,28 +1010,26 @@ int
 
 
 def _grid_ncdimensions(f, key, axis_to_ncdim, g=None):
-    '''
-
-Return a tuple of the netCDF dimension names for the axes of a
+    '''Return a tuple of the netCDF dimension names for the axes of a
 coordinate or cell measures objects.
 
 :Parameters:
 
-    f : cf.Field
+    f: `Field`
 
-    key : str
+    key: `str`
 
-    axis_to_ncdim : dict
+    axis_to_ncdim: `dict`
         Mapping of field axis identifiers to netCDF dimension names.
 
-    g : dict
+    g: `dict`
 
 :Returns:
 
-    out : tuple
+    out: `tuple`
         A tuple of the netCDF dimension names.
 
-'''
+    '''
 #    if f.item(key).ndim == 0:
 #        return ()
 #    else:
@@ -1416,6 +1415,8 @@ variable name.
     else:
         extra['bounds'] = ncvar
 
+    g['bounds'][coord_ncvar] = ncvar
+            
     return extra
 #--- End: def
         
@@ -1487,9 +1488,7 @@ then the input coordinate is not written.
 
 def _write_auxiliary_coordinate(f, key, coord, coordinates,
                                 key_to_ncvar, axis_to_ncdim, g=None):
-    '''
-
-Write an auxiliary coordinate and its bounds to the netCDF file.
+    '''Write an auxiliary coordinate and its bounds to the netCDF file.
 
 If an equal auxiliary coordinate has already been written to the file
 then the input coordinate is not written.
@@ -1522,7 +1521,7 @@ then the input coordinate is not written.
 
 >>> coordinates = _write_auxiliary_coordinate(f, 'aux2', coordinates, g=g)
 
-'''
+    '''
     coord = _change_reference_datetime(coord, g)
 
     ncdimensions = _grid_ncdimensions(f, key, axis_to_ncdim, g=g)
@@ -2137,7 +2136,6 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
                                                            key_to_ncvar,
                                                            axis_to_ncscalar,
                                                            g=g)
-            #--- End: if
         else:
             # --------------------------------------------------------
             # There is no dimension coordinate for this axis
@@ -2226,13 +2224,16 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
     # ----------------------------------------------------------------
     for ref in f.refs('type%formula_terms').values():
         formula_terms = []
-
+        bounds_formula_terms = []
+    
         formula_terms_name = ref.name()
         if formula_terms_name is None:
             owning_coord = None
         else:
             owning_coord = f.coord(formula_terms_name, exact=True)
 
+        z_axis = f.item_axes(formula_terms_name, role=('d', 'a'), exact=True)[0]
+                
         if owning_coord is not None:
             # This formula_terms coordinate reference matches up with
             # an existing coordinate
@@ -2254,16 +2255,27 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
                 if value is None:
                     continue
 
-                anc = f.domain_anc(value)
-                if anc is None:
+                domain_anc = f.domain_anc(value)
+                if domain_anc is None:
                     continue
 
-                if id(anc) not in g['seen']:
+                if id(domain_anc) not in g['seen']:
                     continue
 
-                ncvar = g['seen'][id(anc)]['ncvar']
-
+                # Get the netCDF variable name for the domain
+                # ancillary and add it to the formula_terms attribute
+                ncvar = g['seen'][id(domain_anc)]['ncvar']
                 formula_terms.append('{0}: {1}'.format(term, ncvar))
+
+                bounds = g['bounds'].get(ncvar, None)
+                if bounds is not None:
+                    if z_axis not in f.item_axes(value, role='c'):
+                        bounds = None
+    
+                if bounds is None:        
+                    bounds_formula_terms.append('{0}: {1}'.format(term, ncvar))
+                else:
+                    bounds_formula_terms.append('{0}: {1}'.format(term, bounds))
         #--- End: if
 
         # Add the formula_terms attribute to the output
@@ -2272,6 +2284,17 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
             ncvar = seen[id(owning_coord)]['ncvar']
             g['nc'][ncvar].setncattr('formula_terms',
                                      ' '.join(formula_terms))
+            if g['_debug']:
+                print '  formula_terms =', formula_terms
+    
+            # Add the formula_terms attribute to the coordinate bounds
+            # variable
+            bounds = g['bounds'].get(ncvar)
+            if bounds is not None:
+                bounds_formula_terms = ' '.join(bounds_formula_terms)
+                g['nc'][bounds].setncattr('formula_terms', bounds_formula_terms)
+                if g['_debug']:
+                    print '  Bounds formula_terms =', bounds_formula_terms
     #--- End: for
 
     # ----------------------------------------------------------------
